@@ -118,13 +118,14 @@ class Note(Iaswn):
         _______________________________________________________________________
 
         ATTRIBUTES:
-            o (None|str)infos
-            o (iterable(None|int, None|int))span
+            o (None|str)                     .infos
+            o (iterable(None|int, None|int)) .span
 
         METHODS:
             o __init__(self, infos=None, span=None)
             o __str__(self)
-            o span_ok(self)
+            o .improved_str()
+            o .span_ok(self)
     """
     def __init__(self,
                  infos=None,
@@ -160,6 +161,17 @@ class Note(Iaswn):
 
         return f"({span_x0}, {span_x1})"+str(self.infos)
 
+    def improved_str(self):
+        """
+            Note.improved_str()
+
+            Return an improved version of __str__().
+            ___________________________________________________________________
+
+            RETURNED VALUE: (str)an improved version of __str__()
+        """
+        return f"{self.infos=}; {self.span=};"
+
     def span_ok(self):
         """
             Note.span_ok()
@@ -1038,6 +1050,10 @@ class AnnotatedString(Iaswn, dict):
 
             RETURNED VALUE : a (str)representation of <self>.
         """
+        if self.source_string is None:
+            return f"{self.errors=}; {self._next_unique_id=}; " \
+                "{self.source_string=}; {self._source_string=}; {self.parsingtools=}"
+
         maxl = len(self._source_string)
 
         res = []
